/*
 *  @version 	        @(#)TabbedLoc.java	1.6 98/07/30
 *
 * Copyright (c) 1997-1998 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 */

package suntest.javastar.map.jfc.utils;

import suntest.javastar.lib.*;
import javax.swing.*;
import javax.swing.plaf.TabbedPaneUI;
import java.awt.*;
import java.awt.event.MouseEvent;

/**	
 *  Non Component Locator for JTabbedPane
 *
 *  @date created      Oct 23, 1997
 *  @author	        Mark Hefner
 *
 */

public class TabbedLoc implements JSNonComponentLocator {

  public JSNCLData findObject(Component c, AWTEvent e){
    if(e instanceof MouseEvent){
      int x = ((MouseEvent)e).getX();
      int y = ((MouseEvent)e).getY();
      if(c instanceof JTabbedPane){
	JTabbedPane t = (JTabbedPane)c;
	return findObject(t,x,y);
      }
    }
    return null;
  }

  public static JSNCLData findObject(JTabbedPane t, int x, int y){
    TabbedPaneUI ui = t.getUI();
    if(ui!=null){
      int idx = ui.tabForCoordinate(t,x,y);
      if(idx>-1){
	return getTabDat(t,idx);
      }
    }
    return null;
  }

  public JSNCLData getNamedObjectData(Component c, String wname){
    if(c instanceof JTabbedPane){
      JTabbedPane t = (JTabbedPane)c;
      Parser P = new Parser(wname);
      if(P.Valid){
	return getNamedObjectData(t,P);
      }
    }
    return null;
  }

  public static JSNCLData getNamedObjectData(JTabbedPane t, Parser P){
    TabbedPaneUI ui = t.getUI();
    if(ui!=null){
      int idx = P.Index;
      String rname = P.Value;
      int ct = t.getTabCount();
      if(idx>-1){
	if(idx<ct){
	  if(rname!=null){
	    String name = ""+t.getTitleAt(idx);
	    if(!rname.equals(name)){
	      return null;
	    }
	  }
	  return getTabDat(t,idx);
	}
      } else {
	for(int i=0;i<ct;i++){
	  String name = ""+t.getTitleAt(i);
	  if(name.equals(rname)){
	    return getTabDat(t,i);
	  }
	}
      }
    }
    return null;
  }

  public static JSNCLData getTabDat(JTabbedPane t, int idx){
    Rectangle r = t.getUI().getTabBounds(t,idx);
    String s = t.getTitleAt(idx);
    return new JSNCLData(idx+":"+s, new Point(r.x,r.y), new Integer(idx));
  }

}
