/*
 *  @version 	        @(#)Tree.java	1.11 98/08/07
 *
 * Copyright (c) 1997-1998 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 */

package suntest.javastar.map.jfc.utils;

import suntest.javastar.lib.*;
import javax.swing.*;
import javax.swing.tree.*;
import java.awt.*;
import java.awt.event.MouseEvent;

/**	
 *  Non Component Locator for JTree
 *
 *  @date created      Oct 23, 1997
 *  @author	       Mark Hefner
 *
 */

public class Tree implements JSNonComponentLocator {

  public JSNCLData findObject(Component c, AWTEvent e){
    if(e instanceof MouseEvent){
      int x = ((MouseEvent)e).getX();
      int y = ((MouseEvent)e).getY();
      if(c instanceof JTree){
        JTree t = (JTree)c;
        return findObject(t,x,y);
      }
    }
    return null;
  }

  public static JSNCLData findObject(JTree t, int x, int y){
    TreePath p = t.getClosestPathForLocation(x,y);
    if(p!=null){
      int r = t.getRowForPath(p);
      return getTreeDat(t,r);
    }
    return null;
  }

  public JSNCLData getNamedObjectData(Component c, String wname){
    if(c instanceof JTree){
      JTree t = (JTree)c;
      Parser P = new Parser(wname);
      if(P.Valid){
        return getNamedObjectData(t,P);
      }  else {
        throw new BadRegularExpressionError(wname + " is not a vlid format");
      }
    }
    return null;
  }

  public static JSNCLData getNamedObjectData(JTree t, Parser P){
    int idx = P.Index;
    String rname = P.Value;
    int ct = t.getRowCount();
    if(idx>-1){
      if(idx<ct){
        if(rname!=null){
          String name = rowName(t,idx);
          if(!rname.equals(name)){
            return null;
          }
        }
        return getTreeDat(t,idx);
      }
    } else {
      for(int i=0;i<ct;i++){
        String name = rowName(t,i);
        if(rname.equals(name)){
          return getTreeDat(t,i);
        }
      }
    }
    return null;
  }


  public static JSNCLData getTreeDat(JTree t, int idx){
    String s = rowName(t,idx);
    if(s==null)return null;
    Rectangle rb = t.getRowBounds(idx);
    TreePath p = t.getPathForRow(idx);
    Object o = p;
    if(p!=null){
      Object x = p.getLastPathComponent();
      if(x instanceof TreeNode){
        o = x;
      }
    }
    return new JSNCLData(idx+":"+s, new Point(rb.x,rb.y), o);
  }


  protected static String rowName(JTree t, int i){
    TreePath p = t.getPathForRow(i);
    if(p!=null){
      return toString(p.getPath());
    }
    return null;
  }

  protected static String toString(Object[] a){
    if(a==null)return null;
    String sep = "##";
    String r = "";
    if(a.length>0){
      r = ""+Parser.cleanToString(a[0]);
      for(int i=1;i<a.length;i++){
        r+= sep+Parser.cleanToString(a[i]);
      }
    }
    return r;
  }

}
